==> netbeans_6.5.orig.tar.gz: netbeans-6.5/o.n.core/test/unit/src/org/netbeans/core/DontUseProxyTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2008 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.core;

import org.netbeans.junit.*;

/** Tests HTTP Proxy settings.
 *
 * @author Jiri Rechtacek
 * @see http://www.netbeans.org/issues/show_bug.cgi?id=125588
 */
public class DontUseProxyTest extends NbTestCase {
    public DontUseProxyTest (String name) {
        super (name);
    }
    
    public void testFullIpAdress () {
        String nonProxyHosts = "192.168.1.0|200.100.200.100";
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.0"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.1"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.2.0"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "192.169.1.0"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "193.168.1.0"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.0/1"));
        
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "200.100.200.100"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "200.100.200.200"));
    }
    
    public void testWildcardIpAdress () {
        String nonProxyHosts = "192.*|200.100.200.*";
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.0"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.1"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.2.0"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.169.1.0"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "193.168.1.0"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.0/1"));
        
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "200.100.200.100"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "200.100.200.200"));
    }
    
    public void testWildcardHostName () {
        String nonProxyHosts = "*.netbeans.org|*.other.org|*netbeans.com|*.our.intranet";
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "www.netbeans.org"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "www.netbeans.com"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "www.dummynetbeans.org"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "subversion.our.intranet"));
        
                
    }
    
}

==> netbeans_7.0.1+dfsg1.orig.tar.gz: netbeans-7.0.1+dfsg1/o.n.core/test/unit/src/org/netbeans/core/DontUseProxyTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2008 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

package org.netbeans.core;

import org.netbeans.junit.*;

/** Tests HTTP Proxy settings.
 *
 * @author Jiri Rechtacek
 * @see http://www.netbeans.org/issues/show_bug.cgi?id=125588
 */
public class DontUseProxyTest extends NbTestCase {
    public DontUseProxyTest (String name) {
        super (name);
    }
    
    public void testFullIpAdress () {
        String nonProxyHosts = "192.168.1.0|200.100.200.100";
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.0"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.1"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.2.0"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "192.169.1.0"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "193.168.1.0"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.0/1"));
        
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "200.100.200.100"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "200.100.200.200"));
    }
    
    public void testWildcardIpAdress () {
        String nonProxyHosts = "192.*|200.100.200.*";
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.0"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.1"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.2.0"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.169.1.0"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "193.168.1.0"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "192.168.1.0/1"));
        
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "200.100.200.100"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "200.100.200.200"));
    }
    
    public void testWildcardHostName () {
        String nonProxyHosts = "*.netbeans.org|*.other.org|*netbeans.com|netbeans.org|*.our.intranet|private.*";
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "www.netbeans.org"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "www.netbeans.com"));
        assertFalse (NbProxySelector.dontUseProxy (nonProxyHosts, "www.dummynetbeans.org"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "subversion.our.intranet"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "private"));
        assertTrue (NbProxySelector.dontUseProxy (nonProxyHosts, "private.all"));
    }

}
